@@ -26,11 +26,11 @@
 #include <QIcon>
 #include <QMenu>
 #include <QMouseEvent>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QVariant>
 
 #include <KIconEngine>
-#include <KLazyLocalizedString>
+#include <KIconLoader>
 #include <KMessageBox>
 
 #include <algorithm>
@@ -153,17 +153,18 @@ void TextLabelModeBase::leftReleased(QMouseEvent *e, KigWidget *v, ObjectTypeCal
         p.setObjectName(QStringLiteral("text_label_select_arg_popup"));
         QAction *act = p.addAction(i18n("Name"));
         act->setData(QVariant::fromValue(0));
-        QList<KLazyLocalizedString> l = o->imp()->properties();
-        assert(l.size() == o->imp()->numberOfProperties());
-        for (int i = 0; i < l.size(); ++i) {
-            QString s = l[i].toString();
+        const auto properties = o->imp()->properties();
+        assert(properties.size() == o->imp()->numberOfProperties());
+        int i = 0;
+        for (const auto &property : properties) {
             const char *iconfile = o->imp()->iconForProperty(i);
             if (iconfile && *iconfile) {
-                act = p.addAction(QIcon(new KIconEngine(QLatin1String(iconfile), mdoc.iconLoader())), s);
+                act = p.addAction(QIcon(new KIconEngine(QLatin1String(iconfile), KIconLoader::global())), property.toString());
             } else {
-                act = p.addAction(s);
+                act = p.addAction(property.toString());
             };
             act->setData(QVariant::fromValue(i + 1));
+            i++;
         };
         act = p.exec(v->mapToGlobal(d->plc));
         if (!act)
@@ -180,7 +181,7 @@ void TextLabelModeBase::leftReleased(QMouseEvent *e, KigWidget *v, ObjectTypeCal
                 argcalcer = c;
             }
         } else {
-            assert(result < l.size() + 1);
+            assert(result < properties.size() + 1);
             //      argcalcer = new ObjectPropertyCalcer( o->calcer(), result - 1 );
             argcalcer = new ObjectPropertyCalcer(o->calcer(), result - 1, true);
         }
@@ -271,13 +272,15 @@ void TextLabelModeBase::cancelPressed()
 // also used in textlabelwizard.cc
 uint percentCount(const QString &s)
 {
-    //  QRegExp re( QString::fromUtf8( "%[0-9]" ) );
-    QRegExp re(QLatin1String("%[\\d]+"));
+    //  const QRegularExpression re( QString::fromUtf8( "%[0-9]" ) );
+    const QRegularExpression re(QLatin1String("%[\\d]+"));
     int offset = 0;
     uint percentcount = 0;
-    while ((offset = re.indexIn(s, offset)) != -1) {
+    QRegularExpressionMatch ma(re.match(s, offset));
+    while (ma.hasMatch()) {
         ++percentcount;
-        offset += re.matchedLength();
+        offset += ma.capturedLength();
+        ma = re.match(s, offset);
     };
     return percentcount;
 }
@@ -338,15 +341,17 @@ void TextLabelModeBase::updateLinksLabel()
 {
     LinksLabel::LinksLabelEditBuf buf = d->wiz->linksLabel()->startEdit();
     QString s = d->wiz->text();
-    //  QRegExp re( "%[0-9]" );
-    QRegExp re("%[\\d]+");
+    //  const QRegularExpression re( "%[0-9]" );
+    const QRegularExpression re("%[\\d]+");
     int prevpos = 0;
     int pos = 0;
     uint count = 0;
+    QRegularExpressionMatch ma(re.match(s, pos));
     // we split up the string into text and "links"
-    while ((pos = re.indexIn(s, pos)) != -1) {
+    while (ma.hasMatch()) {
         // prevpos is the first character after the last match, pos is the
         // first char of the current match..
+        pos = ma.capturedStart();
         if (prevpos != pos) {
             // there is a text part between the previous and the current
             // "link"...
@@ -371,8 +376,9 @@ void TextLabelModeBase::updateLinksLabel()
         // set pos and prevpos to the next char after the last match, so
         // we don't enter infinite loops...
         //    pos += 2;
-        pos += re.matchedLength();
+        pos += ma.capturedLength();
         prevpos = pos;
+        ma = re.match(s, pos);
         ++count;
     };
 
