@@ -19,16 +19,15 @@
 #include <algorithm>
 #include <cmath>
 #include <functional>
-#include <math.h>
 
 #include <QStringList>
 
-static const char *constructanglethroughpoint = I18N_NOOP("Construct an angle through this point");
+static const KLazyLocalizedString constructanglethroughpoint = kli18n("Construct an angle through this point");
 
 static const ArgsParser::spec argsspecAngle[] = {
-    {PointImp::stype(), constructanglethroughpoint, I18N_NOOP("Select a point that the first half-line of the angle should go through..."), true},
-    {PointImp::stype(), I18N_NOOP("Construct an angle at this point"), I18N_NOOP("Select the point to construct the angle in..."), true},
-    {PointImp::stype(), constructanglethroughpoint, I18N_NOOP("Select a point that the second half-line of the angle should go through..."), true}};
+    {PointImp::stype(), constructanglethroughpoint, kli18n("Select a point that the first half-line of the angle should go through..."), true},
+    {PointImp::stype(), kli18n("Construct an angle at this point"), kli18n("Select the point to construct the angle in..."), true},
+    {PointImp::stype(), constructanglethroughpoint, kli18n("Select a point that the second half-line of the angle should go through..."), true}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(AngleType)
 
