@@ -345,8 +345,8 @@ const ObjectImpType *CubicImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "cubic",
                                  kli18n("cubic curve"),
-                                 I18N_NOOP("Select this cubic curve"),
-                                 I18N_NOOP("Select cubic curve %1"),
+                                 kli18n("Select this cubic curve"),
+                                 kli18n("Select cubic curve %1"),
                                  kli18n("Remove a Cubic Curve"),
                                  kli18n("Add a Cubic Curve"),
                                  kli18n("Move a Cubic Curve"),
