@@ -542,8 +542,8 @@ const ObjectImpType *AbstractLineImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "line",
                                  kli18n("line"),
-                                 I18N_NOOP("Select a Line"),
-                                 nullptr,
+                                 kli18n("Select a Line"),
+                                 KLazyLocalizedString(),
                                  KLazyLocalizedString(),
                                  KLazyLocalizedString(),
                                  KLazyLocalizedString(),
@@ -558,8 +558,8 @@ const ObjectImpType *LineImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "line",
                                  kli18n("line"),
-                                 I18N_NOOP("Select this line"),
-                                 I18N_NOOP("Select line %1"),
+                                 kli18n("Select this line"),
+                                 kli18n("Select line %1"),
                                  kli18n("Remove a Line"),
                                  kli18n("Add a Line"),
                                  kli18n("Move a Line"),
@@ -574,8 +574,8 @@ const ObjectImpType *SegmentImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "segment",
                                  kli18n("segment"),
-                                 I18N_NOOP("Select this segment"),
-                                 I18N_NOOP("Select segment %1"),
+                                 kli18n("Select this segment"),
+                                 kli18n("Select segment %1"),
                                  kli18n("Remove a Segment"),
                                  kli18n("Add a Segment"),
                                  kli18n("Move a Segment"),
@@ -590,8 +590,8 @@ const ObjectImpType *RayImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "ray",
                                  kli18n("half-line"),
-                                 I18N_NOOP("Select this half-line"),
-                                 I18N_NOOP("Select half-line %1"),
+                                 kli18n("Select this half-line"),
+                                 kli18n("Select half-line %1"),
                                  kli18n("Remove a Half-Line"),
                                  kli18n("Add a Half-Line"),
                                  kli18n("Move a Half-Line"),
