@@ -85,8 +85,8 @@ class ObjectImpType
     const ObjectImpType *mparent;
     const char *minternalname;
     KLazyLocalizedString mtranslatedname;
-    const char *mselectstatement;
-    const char *mselectnamestatement;
+    KLazyLocalizedString mselectstatement;
+    KLazyLocalizedString mselectnamestatement;
     KLazyLocalizedString mremoveastatement;
     KLazyLocalizedString maddastatement;
     KLazyLocalizedString mmoveastatement;
@@ -131,8 +131,8 @@ public:
     explicit ObjectImpType(const ObjectImpType *parent,
                            const char *internalname,
                            const KLazyLocalizedString &translatedname,
-                           const char *selectstatement,
-                           const char *selectnamestatement,
+                           const KLazyLocalizedString &selectstatement,
+                           const KLazyLocalizedString &selectnamestatement,
                            const KLazyLocalizedString &removeastatement,
                            const KLazyLocalizedString &addastatement,
                            const KLazyLocalizedString &moveastatement,
@@ -163,7 +163,7 @@ public:
      * E.g. "Select this segment".  Note that users of this function
      * should use i18n on the returned string before using it.
      */
-    const char *selectStatement() const;
+    QString selectStatement() const;
 
     /**
      * Returns a translatable string of the form "Select point %1".  %1
@@ -171,7 +171,7 @@ public:
      * of the object in question.  This function should be used as
      * follows: i18n( x->selectNameStatement() ).arg( xname ).
      */
-    const char *selectNameStatement() const;
+    QString selectNameStatement() const;
 
     /**
      * Returns a translated string of the form "Remove a xxx".
