@@ -151,8 +151,8 @@ const ObjectImpType *PointImp::stype()
     static const ObjectImpType t(Parent::stype(),
                                  "point",
                                  kli18n("point"),
-                                 I18N_NOOP("Select this point"),
-                                 I18N_NOOP("Select point %1"),
+                                 kli18n("Select this point"),
+                                 kli18n("Select point %1"),
                                  kli18n("Remove a Point"),
                                  kli18n("Add a Point"),
                                  kli18n("Move a Point"),
@@ -194,8 +194,8 @@ const ObjectImpType *BogusPointImp::stype()
     static const ObjectImpType t(nullptr,
                                  "boguspoint",
                                  KLazyLocalizedString(),
-                                 "",
-                                 "",
+                                 KLazyLocalizedString(),
+                                 KLazyLocalizedString(),
                                  KLazyLocalizedString(),
                                  KLazyLocalizedString(),
                                  KLazyLocalizedString(),
