@@ -23,8 +23,8 @@
 #include "../misc/kiginputdialog.h"
 #include "../modes/moving.h"
 
-static const ArgsParser::spec argsspecFixedPoint[] = {{DoubleImp::stype(), "x", "SHOULD NOT BE SEEN", false},
-                                                      {DoubleImp::stype(), "y", "SHOULD NOT BE SEEN", false}};
+static const ArgsParser::spec argsspecFixedPoint[] = {{DoubleImp::stype(), "x", {}, false},
+                                                      {DoubleImp::stype(), "y", {}, false}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(FixedPointType)
 
@@ -48,9 +48,9 @@ ObjectImp *FixedPointType::calc(const Args &parents, const KigDocument &) const
     return new PointImp(Coordinate(a, b));
 }
 
-static const ArgsParser::spec argsspecRelativePoint[] = {{DoubleImp::stype(), "relative-x", "SHOULD NOT BE SEEN", false},
-                                                         {DoubleImp::stype(), "relative-y", "SHOULD NOT BE SEEN", false},
-                                                         {ObjectImp::stype(), "object", "SHOULD NOT BE SEEN", false}};
+static const ArgsParser::spec argsspecRelativePoint[] = {{DoubleImp::stype(), "relative-x", {}, false},
+                                                         {DoubleImp::stype(), "relative-y", {}, false},
+                                                         {ObjectImp::stype(), "object", {}, false}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(RelativePointType)
 
@@ -123,8 +123,8 @@ ObjectImp *ConstrainedPointType::calc(const Args &parents, const KigDocument &do
         return new InvalidImp;
 }
 
-const ArgsParser::spec argsspecConstrainedPoint[] = {{DoubleImp::stype(), "parameter", "SHOULD NOT BE SEEN", false},
-                                                     {CurveImp::stype(), "Constrain the point to this curve", "SHOULD NOT BE SEEN", true}};
+const ArgsParser::spec argsspecConstrainedPoint[] = {{DoubleImp::stype(), "parameter", {}, false},
+                                                     {CurveImp::stype(), "Constrain the point to this curve", {}, true}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(ConstrainedPointType)
 
@@ -239,12 +239,12 @@ bool CursorPointType::canMove(const ObjectTypeCalcer &) const
 }
 
 static const ArgsParser::spec argsspecMidPoint[] = {{PointImp::stype(),
-                                                     I18N_NOOP("Construct the midpoint of this point and another point"),
-                                                     I18N_NOOP("Select the first of the two points of which you want to construct the midpoint..."),
+                                                     kli18n("Construct the midpoint of this point and another point"),
+                                                     kli18n("Select the first of the two points of which you want to construct the midpoint..."),
                                                      false},
                                                     {PointImp::stype(),
-                                                     I18N_NOOP("Construct the midpoint of this point and another point"),
-                                                     I18N_NOOP("Select the other of the two points of which you want to construct the midpoint..."),
+                                                     kli18n("Construct the midpoint of this point and another point"),
+                                                     kli18n("Select the other of the two points of which you want to construct the midpoint..."),
                                                      false}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(MidPointType)
@@ -271,12 +271,12 @@ ObjectImp *MidPointType::calcx(const Coordinate &a, const Coordinate &b) const
 
 static const ArgsParser::spec argsspecGoldenPoint[] = {
     {PointImp::stype(),
-     I18N_NOOP("Construct the golden ratio point of this point and another point"),
-     I18N_NOOP("Select the first of the two points of which you want to construct the golden ratio point..."),
+     kli18n("Construct the golden ratio point of this point and another point"),
+     kli18n("Select the first of the two points of which you want to construct the golden ratio point..."),
      false},
     {PointImp::stype(),
-     I18N_NOOP("Construct the golden ratio point of this point and another point"),
-     I18N_NOOP("Select the other of the two points of which you want to construct the golden ratio point..."),
+     kli18n("Construct the golden ratio point of this point and another point"),
+     kli18n("Select the other of the two points of which you want to construct the golden ratio point..."),
      false}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(GoldenPointType)
@@ -504,10 +504,10 @@ std::vector<ObjectCalcer *> ConstrainedPointType::movableParents(const ObjectTyp
     return ret;
 }
 
-static const ArgsParser::spec argsspecConstrainedRelativePoint[] = {{DoubleImp::stype(), "relative-x", "SHOULD NOT BE SEEN", false},
-                                                                    {DoubleImp::stype(), "relative-y", "SHOULD NOT BE SEEN", false},
-                                                                    {DoubleImp::stype(), "parameter", "SHOULD NOT BE SEEN", false},
-                                                                    {CurveImp::stype(), "curve", "SHOULD NOT BE SEEN", false}};
+static const ArgsParser::spec argsspecConstrainedRelativePoint[] = {{DoubleImp::stype(), "relative-x", {}, false},
+                                                                    {DoubleImp::stype(), "relative-y", {}, false},
+                                                                    {DoubleImp::stype(), "parameter", {}, false},
+                                                                    {CurveImp::stype(), "curve", {}, false}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(ConstrainedRelativePointType)
 
@@ -740,9 +740,9 @@ ObjectImp *MeasureTransportTypeOld::calc(const Args &parents, const KigDocument
 }
 
 static const ArgsParser::spec argsspecMeasureTransportOld[] = {
-    {CircleImp::stype(), "Transport a measure on this circle", I18N_NOOP("Select the circle on which to transport a measure..."), true},
-    {PointImp::stype(), "Start transport from this point of the circle", I18N_NOOP("Select a point on the circle..."), false},
-    {SegmentImp::stype(), "Segment to transport", I18N_NOOP("Select the segment to transport on the circle..."), false}};
+    {CircleImp::stype(), "Transport a measure on this circle", kli18n("Select the circle on which to transport a measure..."), true},
+    {PointImp::stype(), "Start transport from this point of the circle", kli18n("Select a point on the circle..."), false},
+    {SegmentImp::stype(), "Segment to transport", kli18n("Select the segment to transport on the circle..."), false}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(MeasureTransportTypeOld)
 
@@ -791,8 +791,8 @@ ObjectImp *PointByCoordsType::calc(const Args &parents, const KigDocument &) con
 }
 
 static const ArgsParser::spec argsspecPointByCoords[] = {
-    {&lengthimptypeinstance, "X coordinate given by this number/length", I18N_NOOP("Select a number/length as x coordinate of the point..."), false},
-    {&lengthimptypeinstance, "Y coordinate given by this number/length", I18N_NOOP("Select a number/length as y coordinate of the point..."), false}};
+    {&lengthimptypeinstance, "X coordinate given by this number/length", kli18n("Select a number/length as x coordinate of the point..."), false},
+    {&lengthimptypeinstance, "Y coordinate given by this number/length", kli18n("Select a number/length as y coordinate of the point..."), false}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(PointByCoordsType)
 
@@ -817,8 +817,8 @@ const ObjectImpType *PointByCoordsType::resultId() const
 }
 
 static const ArgsParser::spec argsspecProjectedPoint[] = {
-    {PointImp::stype(), "Point to project", I18N_NOOP("Select a point to project onto a line..."), false},
-    {AbstractLineImp::stype(), "Line where to project", I18N_NOOP("Line where the projected point will lie..."), true}};
+    {PointImp::stype(), "Point to project", kli18n("Select a point to project onto a line..."), false},
+    {AbstractLineImp::stype(), "Line where to project", kli18n("Line where the projected point will lie..."), true}};
 
 KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE(ProjectedPointType)
 
