@@ -40,7 +40,7 @@ PythonCompiledScriptImp::PythonCompiledScriptImp(const CompiledPythonScript &s)
 
 const ObjectImpType *PythonCompiledScriptImp::stype()
 {
-    static const ObjectImpType t(BogusImp::stype(), "python-compiled-script-imp", {}, 0, 0, {}, {}, {}, {}, {}, {});
+    static const ObjectImpType t(BogusImp::stype(), "python-compiled-script-imp", {}, {}, {}, {}, {}, {}, {}, {}, {});
     return &t;
 }
 
